{% extends 'layout.html' %}
{% block content %}
<h1>Metrics</h1>
<div class="ui fluid icon input" style="margin-bottom:20px">
  <input autofocus="autofocus" class="filter-list" placeholder="Type here to filter...">
</div>
<ul class="ui list searchable">
  {% for metric in metrics %}
  <li>
    <a href="{{url_for('metric', env=current_env, metric=metric)}}">{{metric}}</a>
  </li>
  {% endfor %}
</ul>
{% endblock content %}
